Coverage for C:\src\imod-python\imod\prepare\topsystem\__init__.py: 100%

1 from imod.prepare.topsystem.allocation import (

2 ALLOCATION_OPTION,

3 allocate_drn_cells,

4 allocate_ghb_cells,

5 allocate_rch_cells,

6 allocate_riv_cells,

7)

8 from imod.prepare.topsystem.conductance import (

9 DISTRIBUTING_OPTION,

10 distribute_drn_conductance,

11 distribute_ghb_conductance,

12 distribute_riv_conductance,

13)

14 from imod.prepare.topsystem.resistance import c_leakage, c_radial